# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/permission_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/permission_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)fsai_grpc_api/protos/permission_api.proto\x1a fsai_grpc_api/protos/utils.proto\"7\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07role_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"@\n\x1d\x46indOrCreatePermissionRequest\x12\x1f\n\npermission\x18\x01 \x01(\x0b\x32\x0b.Permission\"c\n\x1e\x46indOrCreatePermissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1f\n\npermission\x18\x02 \x01(\x0b\x32\x0b.Permission\")\n\x16ListPermissionsRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\x05\"]\n\x17ListPermissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bpermissions\x18\x02 \x03(\x0b\x32\x0b.Permission2\xb0\x01\n\rPermissionApi\x12Y\n\x16\x46indOrCreatePermission\x12\x1e.FindOrCreatePermissionRequest\x1a\x1f.FindOrCreatePermissionResponse\x12\x44\n\x0fListPermissions\x12\x17.ListPermissionsRequest\x1a\x18.ListPermissionsResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Permission.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_id', full_name='Permission.role_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Permission.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=134,
)


_FINDORCREATEPERMISSIONREQUEST = _descriptor.Descriptor(
  name='FindOrCreatePermissionRequest',
  full_name='FindOrCreatePermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='FindOrCreatePermissionRequest.permission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=200,
)


_FINDORCREATEPERMISSIONRESPONSE = _descriptor.Descriptor(
  name='FindOrCreatePermissionResponse',
  full_name='FindOrCreatePermissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreatePermissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='FindOrCreatePermissionResponse.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=301,
)


_LISTPERMISSIONSREQUEST = _descriptor.Descriptor(
  name='ListPermissionsRequest',
  full_name='ListPermissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='ListPermissionsRequest.role_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=344,
)


_LISTPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ListPermissionsResponse',
  full_name='ListPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListPermissionsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='ListPermissionsResponse.permissions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=439,
)

_FINDORCREATEPERMISSIONREQUEST.fields_by_name['permission'].message_type = _PERMISSION
_FINDORCREATEPERMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEPERMISSIONRESPONSE.fields_by_name['permission'].message_type = _PERMISSION
_LISTPERMISSIONSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTPERMISSIONSRESPONSE.fields_by_name['permissions'].message_type = _PERMISSION
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['FindOrCreatePermissionRequest'] = _FINDORCREATEPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreatePermissionResponse'] = _FINDORCREATEPERMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListPermissionsRequest'] = _LISTPERMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPermissionsResponse'] = _LISTPERMISSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:Permission)
  })
_sym_db.RegisterMessage(Permission)

FindOrCreatePermissionRequest = _reflection.GeneratedProtocolMessageType('FindOrCreatePermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEPERMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreatePermissionRequest)
  })
_sym_db.RegisterMessage(FindOrCreatePermissionRequest)

FindOrCreatePermissionResponse = _reflection.GeneratedProtocolMessageType('FindOrCreatePermissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEPERMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreatePermissionResponse)
  })
_sym_db.RegisterMessage(FindOrCreatePermissionResponse)

ListPermissionsRequest = _reflection.GeneratedProtocolMessageType('ListPermissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListPermissionsRequest)
  })
_sym_db.RegisterMessage(ListPermissionsRequest)

ListPermissionsResponse = _reflection.GeneratedProtocolMessageType('ListPermissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.permission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListPermissionsResponse)
  })
_sym_db.RegisterMessage(ListPermissionsResponse)



_PERMISSIONAPI = _descriptor.ServiceDescriptor(
  name='PermissionApi',
  full_name='PermissionApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=442,
  serialized_end=618,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreatePermission',
    full_name='PermissionApi.FindOrCreatePermission',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEPERMISSIONREQUEST,
    output_type=_FINDORCREATEPERMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPermissions',
    full_name='PermissionApi.ListPermissions',
    index=1,
    containing_service=None,
    input_type=_LISTPERMISSIONSREQUEST,
    output_type=_LISTPERMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PERMISSIONAPI)

DESCRIPTOR.services_by_name['PermissionApi'] = _PERMISSIONAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_analyzer_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/workflow_analyzer_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0fsai_grpc_api/protos/workflow_analyzer_api.proto\"M\n GetEstimatesByTotalAoiKm2Request\x12\x15\n\rtotal_aoi_km2\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"L\n GetEstimatesByTotalImagesRequest\x12\x14\n\x0ctotal_images\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"4\n\x1eGetEstimatesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"v\n\x14WorkflowAnalyzerCost\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"w\n\x15WorkflowAnalyzerHours\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"|\n\x18WorkflowAnalyzerResponse\x12\x14\n\x0c\x62\x61tch_number\x18\x01 \x01(\x05\x12#\n\x04\x63ost\x18\x05 \x01(\x0b\x32\x15.WorkflowAnalyzerCost\x12%\n\x05hours\x18\x06 \x01(\x0b\x32\x16.WorkflowAnalyzerHours2\xa2\x02\n\x13WorkflowAnalyzerApi\x12Y\n\x19GetEstimatesByTotalAoiKm2\x12!.GetEstimatesByTotalAoiKm2Request\x1a\x19.WorkflowAnalyzerResponse\x12Y\n\x19GetEstimatesByTotalImages\x12!.GetEstimatesByTotalImagesRequest\x1a\x19.WorkflowAnalyzerResponse\x12U\n\x17GetEstimatesByMissionId\x12\x1f.GetEstimatesByMissionIdRequest\x1a\x19.WorkflowAnalyzerResponseb\x06proto3'
)




_GETESTIMATESBYTOTALAOIKM2REQUEST = _descriptor.Descriptor(
  name='GetEstimatesByTotalAoiKm2Request',
  full_name='GetEstimatesByTotalAoiKm2Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_aoi_km2', full_name='GetEstimatesByTotalAoiKm2Request.total_aoi_km2', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_size', full_name='GetEstimatesByTotalAoiKm2Request.batch_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=129,
)


_GETESTIMATESBYTOTALIMAGESREQUEST = _descriptor.Descriptor(
  name='GetEstimatesByTotalImagesRequest',
  full_name='GetEstimatesByTotalImagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_images', full_name='GetEstimatesByTotalImagesRequest.total_images', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_size', full_name='GetEstimatesByTotalImagesRequest.batch_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=207,
)


_GETESTIMATESBYMISSIONIDREQUEST = _descriptor.Descriptor(
  name='GetEstimatesByMissionIdRequest',
  full_name='GetEstimatesByMissionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetEstimatesByMissionIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=261,
)


_WORKFLOWANALYZERCOST = _descriptor.Descriptor(
  name='WorkflowAnalyzerCost',
  full_name='WorkflowAnalyzerCost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_acquisition', full_name='WorkflowAnalyzerCost.feature_acquisition', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_acquisition', full_name='WorkflowAnalyzerCost.image_acquisition', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_inference', full_name='WorkflowAnalyzerCost.image_inference', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='WorkflowAnalyzerCost.total', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=381,
)


_WORKFLOWANALYZERHOURS = _descriptor.Descriptor(
  name='WorkflowAnalyzerHours',
  full_name='WorkflowAnalyzerHours',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_acquisition', full_name='WorkflowAnalyzerHours.feature_acquisition', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_acquisition', full_name='WorkflowAnalyzerHours.image_acquisition', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_inference', full_name='WorkflowAnalyzerHours.image_inference', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='WorkflowAnalyzerHours.total', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=502,
)


_WORKFLOWANALYZERRESPONSE = _descriptor.Descriptor(
  name='WorkflowAnalyzerResponse',
  full_name='WorkflowAnalyzerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_number', full_name='WorkflowAnalyzerResponse.batch_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='WorkflowAnalyzerResponse.cost', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hours', full_name='WorkflowAnalyzerResponse.hours', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=628,
)

_WORKFLOWANALYZERRESPONSE.fields_by_name['cost'].message_type = _WORKFLOWANALYZERCOST
_WORKFLOWANALYZERRESPONSE.fields_by_name['hours'].message_type = _WORKFLOWANALYZERHOURS
DESCRIPTOR.message_types_by_name['GetEstimatesByTotalAoiKm2Request'] = _GETESTIMATESBYTOTALAOIKM2REQUEST
DESCRIPTOR.message_types_by_name['GetEstimatesByTotalImagesRequest'] = _GETESTIMATESBYTOTALIMAGESREQUEST
DESCRIPTOR.message_types_by_name['GetEstimatesByMissionIdRequest'] = _GETESTIMATESBYMISSIONIDREQUEST
DESCRIPTOR.message_types_by_name['WorkflowAnalyzerCost'] = _WORKFLOWANALYZERCOST
DESCRIPTOR.message_types_by_name['WorkflowAnalyzerHours'] = _WORKFLOWANALYZERHOURS
DESCRIPTOR.message_types_by_name['WorkflowAnalyzerResponse'] = _WORKFLOWANALYZERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetEstimatesByTotalAoiKm2Request = _reflection.GeneratedProtocolMessageType('GetEstimatesByTotalAoiKm2Request', (_message.Message,), {
  'DESCRIPTOR' : _GETESTIMATESBYTOTALAOIKM2REQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:GetEstimatesByTotalAoiKm2Request)
  })
_sym_db.RegisterMessage(GetEstimatesByTotalAoiKm2Request)

GetEstimatesByTotalImagesRequest = _reflection.GeneratedProtocolMessageType('GetEstimatesByTotalImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETESTIMATESBYTOTALIMAGESREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:GetEstimatesByTotalImagesRequest)
  })
_sym_db.RegisterMessage(GetEstimatesByTotalImagesRequest)

GetEstimatesByMissionIdRequest = _reflection.GeneratedProtocolMessageType('GetEstimatesByMissionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETESTIMATESBYMISSIONIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:GetEstimatesByMissionIdRequest)
  })
_sym_db.RegisterMessage(GetEstimatesByMissionIdRequest)

WorkflowAnalyzerCost = _reflection.GeneratedProtocolMessageType('WorkflowAnalyzerCost', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWANALYZERCOST,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowAnalyzerCost)
  })
_sym_db.RegisterMessage(WorkflowAnalyzerCost)

WorkflowAnalyzerHours = _reflection.GeneratedProtocolMessageType('WorkflowAnalyzerHours', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWANALYZERHOURS,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowAnalyzerHours)
  })
_sym_db.RegisterMessage(WorkflowAnalyzerHours)

WorkflowAnalyzerResponse = _reflection.GeneratedProtocolMessageType('WorkflowAnalyzerResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWANALYZERRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_analyzer_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowAnalyzerResponse)
  })
_sym_db.RegisterMessage(WorkflowAnalyzerResponse)



_WORKFLOWANALYZERAPI = _descriptor.ServiceDescriptor(
  name='WorkflowAnalyzerApi',
  full_name='WorkflowAnalyzerApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=631,
  serialized_end=921,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEstimatesByTotalAoiKm2',
    full_name='WorkflowAnalyzerApi.GetEstimatesByTotalAoiKm2',
    index=0,
    containing_service=None,
    input_type=_GETESTIMATESBYTOTALAOIKM2REQUEST,
    output_type=_WORKFLOWANALYZERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEstimatesByTotalImages',
    full_name='WorkflowAnalyzerApi.GetEstimatesByTotalImages',
    index=1,
    containing_service=None,
    input_type=_GETESTIMATESBYTOTALIMAGESREQUEST,
    output_type=_WORKFLOWANALYZERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEstimatesByMissionId',
    full_name='WorkflowAnalyzerApi.GetEstimatesByMissionId',
    index=2,
    containing_service=None,
    input_type=_GETESTIMATESBYMISSIONIDREQUEST,
    output_type=_WORKFLOWANALYZERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWANALYZERAPI)

DESCRIPTOR.services_by_name['WorkflowAnalyzerApi'] = _WORKFLOWANALYZERAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/mission_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/mission_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&fsai_grpc_api/protos/mission_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\x98\x01\n\x07Mission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x14\x43reateMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x43reateMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"0\n\x13ListMissionsRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x14ListMissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1a\n\x08missions\x18\x02 \x03(\x0b\x32\x08.Mission\"3\n\x16\x46indMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"V\n\x17\x46indMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"=\n LockMissionAreaOfInterestRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"`\n!LockMissionAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"1\n\x14\x44\x65leteMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x15\x44\x65leteMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"5\n\x18UpdateMissionByIdRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"X\n\x19UpdateMissionByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission2\xbf\x03\n\nMissionApi\x12>\n\rCreateMission\x12\x15.CreateMissionRequest\x1a\x16.CreateMissionResponse\x12;\n\x0cListMissions\x12\x14.ListMissionsRequest\x1a\x15.ListMissionsResponse\x12\x44\n\x0f\x46indMissionById\x12\x17.FindMissionByIdRequest\x1a\x18.FindMissionByIdResponse\x12\x62\n\x19LockMissionAreaOfInterest\x12!.LockMissionAreaOfInterestRequest\x1a\".LockMissionAreaOfInterestResponse\x12>\n\rDeleteMission\x12\x15.DeleteMissionRequest\x1a\x16.DeleteMissionResponse\x12J\n\x11UpdateMissionById\x12\x19.UpdateMissionByIdRequest\x1a\x1a.UpdateMissionByIdResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_MISSION = _descriptor.Descriptor(
  name='Mission',
  full_name='Mission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Mission.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Mission.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Mission.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Mission.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Mission.updated_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=262,
)


_CREATEMISSIONREQUEST = _descriptor.Descriptor(
  name='CreateMissionRequest',
  full_name='CreateMissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='CreateMissionRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=313,
)


_CREATEMISSIONRESPONSE = _descriptor.Descriptor(
  name='CreateMissionResponse',
  full_name='CreateMissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CreateMissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='CreateMissionResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=399,
)


_LISTMISSIONSREQUEST = _descriptor.Descriptor(
  name='ListMissionsRequest',
  full_name='ListMissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='ListMissionsRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=449,
)


_LISTMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ListMissionsResponse',
  full_name='ListMissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missions', full_name='ListMissionsResponse.missions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=535,
)


_FINDMISSIONBYIDREQUEST = _descriptor.Descriptor(
  name='FindMissionByIdRequest',
  full_name='FindMissionByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindMissionByIdRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=588,
)


_FINDMISSIONBYIDRESPONSE = _descriptor.Descriptor(
  name='FindMissionByIdResponse',
  full_name='FindMissionByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindMissionByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindMissionByIdResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=676,
)


_LOCKMISSIONAREAOFINTERESTREQUEST = _descriptor.Descriptor(
  name='LockMissionAreaOfInterestRequest',
  full_name='LockMissionAreaOfInterestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='LockMissionAreaOfInterestRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=739,
)


_LOCKMISSIONAREAOFINTERESTRESPONSE = _descriptor.Descriptor(
  name='LockMissionAreaOfInterestResponse',
  full_name='LockMissionAreaOfInterestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='LockMissionAreaOfInterestResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='LockMissionAreaOfInterestResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=837,
)


_DELETEMISSIONREQUEST = _descriptor.Descriptor(
  name='DeleteMissionRequest',
  full_name='DeleteMissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='DeleteMissionRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=888,
)


_DELETEMISSIONRESPONSE = _descriptor.Descriptor(
  name='DeleteMissionResponse',
  full_name='DeleteMissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteMissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='DeleteMissionResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=974,
)


_UPDATEMISSIONBYIDREQUEST = _descriptor.Descriptor(
  name='UpdateMissionByIdRequest',
  full_name='UpdateMissionByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='UpdateMissionByIdRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1029,
)


_UPDATEMISSIONBYIDRESPONSE = _descriptor.Descriptor(
  name='UpdateMissionByIdResponse',
  full_name='UpdateMissionByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateMissionByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='UpdateMissionByIdResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1119,
)

_MISSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MISSION.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEMISSIONREQUEST.fields_by_name['mission'].message_type = _MISSION
_CREATEMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CREATEMISSIONRESPONSE.fields_by_name['mission'].message_type = _MISSION
_LISTMISSIONSREQUEST.fields_by_name['mission'].message_type = _MISSION
_LISTMISSIONSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONSRESPONSE.fields_by_name['missions'].message_type = _MISSION
_FINDMISSIONBYIDREQUEST.fields_by_name['mission'].message_type = _MISSION
_FINDMISSIONBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDMISSIONBYIDRESPONSE.fields_by_name['mission'].message_type = _MISSION
_LOCKMISSIONAREAOFINTERESTREQUEST.fields_by_name['mission'].message_type = _MISSION
_LOCKMISSIONAREAOFINTERESTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LOCKMISSIONAREAOFINTERESTRESPONSE.fields_by_name['mission'].message_type = _MISSION
_DELETEMISSIONREQUEST.fields_by_name['mission'].message_type = _MISSION
_DELETEMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEMISSIONRESPONSE.fields_by_name['mission'].message_type = _MISSION
_UPDATEMISSIONBYIDREQUEST.fields_by_name['mission'].message_type = _MISSION
_UPDATEMISSIONBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEMISSIONBYIDRESPONSE.fields_by_name['mission'].message_type = _MISSION
DESCRIPTOR.message_types_by_name['Mission'] = _MISSION
DESCRIPTOR.message_types_by_name['CreateMissionRequest'] = _CREATEMISSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateMissionResponse'] = _CREATEMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionsRequest'] = _LISTMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionsResponse'] = _LISTMISSIONSRESPONSE
DESCRIPTOR.message_types_by_name['FindMissionByIdRequest'] = _FINDMISSIONBYIDREQUEST
DESCRIPTOR.message_types_by_name['FindMissionByIdResponse'] = _FINDMISSIONBYIDRESPONSE
DESCRIPTOR.message_types_by_name['LockMissionAreaOfInterestRequest'] = _LOCKMISSIONAREAOFINTERESTREQUEST
DESCRIPTOR.message_types_by_name['LockMissionAreaOfInterestResponse'] = _LOCKMISSIONAREAOFINTERESTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteMissionRequest'] = _DELETEMISSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteMissionResponse'] = _DELETEMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateMissionByIdRequest'] = _UPDATEMISSIONBYIDREQUEST
DESCRIPTOR.message_types_by_name['UpdateMissionByIdResponse'] = _UPDATEMISSIONBYIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Mission = _reflection.GeneratedProtocolMessageType('Mission', (_message.Message,), {
  'DESCRIPTOR' : _MISSION,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:Mission)
  })
_sym_db.RegisterMessage(Mission)

CreateMissionRequest = _reflection.GeneratedProtocolMessageType('CreateMissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateMissionRequest)
  })
_sym_db.RegisterMessage(CreateMissionRequest)

CreateMissionResponse = _reflection.GeneratedProtocolMessageType('CreateMissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateMissionResponse)
  })
_sym_db.RegisterMessage(CreateMissionResponse)

ListMissionsRequest = _reflection.GeneratedProtocolMessageType('ListMissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionsRequest)
  })
_sym_db.RegisterMessage(ListMissionsRequest)

ListMissionsResponse = _reflection.GeneratedProtocolMessageType('ListMissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionsResponse)
  })
_sym_db.RegisterMessage(ListMissionsResponse)

FindMissionByIdRequest = _reflection.GeneratedProtocolMessageType('FindMissionByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionByIdRequest)
  })
_sym_db.RegisterMessage(FindMissionByIdRequest)

FindMissionByIdResponse = _reflection.GeneratedProtocolMessageType('FindMissionByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionByIdResponse)
  })
_sym_db.RegisterMessage(FindMissionByIdResponse)

LockMissionAreaOfInterestRequest = _reflection.GeneratedProtocolMessageType('LockMissionAreaOfInterestRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKMISSIONAREAOFINTERESTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:LockMissionAreaOfInterestRequest)
  })
_sym_db.RegisterMessage(LockMissionAreaOfInterestRequest)

LockMissionAreaOfInterestResponse = _reflection.GeneratedProtocolMessageType('LockMissionAreaOfInterestResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKMISSIONAREAOFINTERESTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:LockMissionAreaOfInterestResponse)
  })
_sym_db.RegisterMessage(LockMissionAreaOfInterestResponse)

DeleteMissionRequest = _reflection.GeneratedProtocolMessageType('DeleteMissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteMissionRequest)
  })
_sym_db.RegisterMessage(DeleteMissionRequest)

DeleteMissionResponse = _reflection.GeneratedProtocolMessageType('DeleteMissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteMissionResponse)
  })
_sym_db.RegisterMessage(DeleteMissionResponse)

UpdateMissionByIdRequest = _reflection.GeneratedProtocolMessageType('UpdateMissionByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMISSIONBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateMissionByIdRequest)
  })
_sym_db.RegisterMessage(UpdateMissionByIdRequest)

UpdateMissionByIdResponse = _reflection.GeneratedProtocolMessageType('UpdateMissionByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMISSIONBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateMissionByIdResponse)
  })
_sym_db.RegisterMessage(UpdateMissionByIdResponse)



_MISSIONAPI = _descriptor.ServiceDescriptor(
  name='MissionApi',
  full_name='MissionApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1122,
  serialized_end=1569,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateMission',
    full_name='MissionApi.CreateMission',
    index=0,
    containing_service=None,
    input_type=_CREATEMISSIONREQUEST,
    output_type=_CREATEMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissions',
    full_name='MissionApi.ListMissions',
    index=1,
    containing_service=None,
    input_type=_LISTMISSIONSREQUEST,
    output_type=_LISTMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindMissionById',
    full_name='MissionApi.FindMissionById',
    index=2,
    containing_service=None,
    input_type=_FINDMISSIONBYIDREQUEST,
    output_type=_FINDMISSIONBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LockMissionAreaOfInterest',
    full_name='MissionApi.LockMissionAreaOfInterest',
    index=3,
    containing_service=None,
    input_type=_LOCKMISSIONAREAOFINTERESTREQUEST,
    output_type=_LOCKMISSIONAREAOFINTERESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMission',
    full_name='MissionApi.DeleteMission',
    index=4,
    containing_service=None,
    input_type=_DELETEMISSIONREQUEST,
    output_type=_DELETEMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMissionById',
    full_name='MissionApi.UpdateMissionById',
    index=5,
    containing_service=None,
    input_type=_UPDATEMISSIONBYIDREQUEST,
    output_type=_UPDATEMISSIONBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MISSIONAPI)

DESCRIPTOR.services_by_name['MissionApi'] = _MISSIONAPI

# @@protoc_insertion_point(module_scope)
